@@ -13,11 +13,14 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5620 $
-## |  Last changed: $Date: 2021-12-06 17:15:42 +0100 (Mo, 06 Dez 2021) $
+## |  File version: $Revision: 5686 $
+## |  Last changed: $Date: 2022-01-06 10:56:00 +0100 (Do, 06 Jan 2022) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
+#' @include f_core_utilities.R
+NULL
+
 #' @title
 #' Get Analysis Results
 #'
@@ -174,8 +177,10 @@ getAnalysisResults <- function(design, dataInput, ...,
             if (!is.null(status) && status %in% c("under-running", "over-running") &&
                     length(observedInformationRates) > 1) {
                 if (stageFromData == 1) {
-                    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, 
-                        "Recalculation of the information rates not possible at stage 1")
+                    stop(
+                        C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
+                        "Recalculation of the information rates not possible at stage 1"
+                    )
                 }
 
                 if (!(getLogLevel() %in% c(C_LOG_LEVEL_DISABLED, C_LOG_LEVEL_PROGRESS))) {
@@ -340,7 +345,7 @@ getAnalysisResults <- function(design, dataInput, ...,
         }
 
         if (is.null(result)) {
-            stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", class(dataInput), "' is not implemented yet")
+            stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", .getClassName(dataInput), "' is not implemented yet")
         }
 
         if (informationRatesRecalculated) {
@@ -356,13 +361,19 @@ getAnalysisResults <- function(design, dataInput, ...,
     if (!is.null(result) && !is.null(repeatedPValues)) {
         result$repeatedPValues <- repeatedPValues
     }
-    
-    if (design$kMax > 1 && .isTrialDesignInverseNormalOrGroupSequential(design) && 
+
+    if (design$kMax > 1 && .isTrialDesignInverseNormalOrGroupSequential(design) &&
             design$typeOfDesign %in% c(C_TYPE_OF_DESIGN_AS_USER, C_TYPE_OF_DESIGN_NO_EARLY_EFFICACY)) {
         indices <- design$userAlphaSpending == 0
-        result$repeatedConfidenceIntervalLowerBounds[indices] <- NA_real_
-        result$repeatedConfidenceIntervalUpperBounds[indices] <- NA_real_
-        result$repeatedPValues[indices] <- NA_real_
+        if (.isEnrichmentDataset(dataInput) || .isMultiArmDataset(dataInput)) {
+            result$repeatedConfidenceIntervalLowerBounds[, indices] <- NA_real_
+            result$repeatedConfidenceIntervalUpperBounds[, indices] <- NA_real_
+            result$repeatedPValues[, indices] <- NA_real_
+        } else {
+            result$repeatedConfidenceIntervalLowerBounds[indices] <- NA_real_
+            result$repeatedConfidenceIntervalUpperBounds[indices] <- NA_real_
+            result$repeatedPValues[indices] <- NA_real_
+        }
     }
 
     options("rpact.analyis.repeated.p.values.warnings.enabled" = "TRUE")
@@ -483,7 +494,7 @@ getStageResults <- function(design, dataInput, ..., stage = NA_integer_) {
         ))
     }
 
-    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", class(dataInput), "' is not supported")
+    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", .getClassName(dataInput), "' is not supported")
 }
 
 .getStageFromOptionalArguments <- function(..., dataInput, design, showWarnings = FALSE) {
@@ -753,7 +764,7 @@ getRepeatedConfidenceIntervals <- function(design, dataInput, ...,
         ))
     }
 
-    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", class(dataInput), "' is not implemented yet")
+    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", .getClassName(dataInput), "' is not implemented yet")
 }
 
 .getStageResultsObject <- function(stageResults, ..., functionName) {
@@ -893,7 +904,7 @@ getConditionalPower <- function(stageResults, ..., nPlanned,
     } else {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '",
-            class(stageResults$.dataInput), "' is not implemented yet"
+            .getClassName(stageResults$.dataInput), "' is not implemented yet"
         )
     }
 }
@@ -950,7 +961,7 @@ getConditionalPower <- function(stageResults, ..., nPlanned,
 
     stop(
         C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '",
-        class(stageResults$.dataInput), "' is not implemented yet"
+        .getClassName(stageResults$.dataInput), "' is not implemented yet"
     )
 }
 
@@ -1532,7 +1543,7 @@ getFinalConfidenceInterval <- function(design, dataInput, ...,
         ))
     }
 
-    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", class(dataInput), "' is not implemented yet")
+    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", .getClassName(dataInput), "' is not implemented yet")
 }
 
 
