@@ -13,9 +13,9 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5594 $
-## |  Last changed: $Date: 2021-11-26 15:24:35 +0100 (Fr, 26 Nov 2021) $
-## |  Last changed by: $Author: pahlke $
+## |  File version: $Revision: 5747 $
+## |  Last changed: $Date: 2022-01-24 12:14:58 +0100 (Mo, 24 Jan 2022) $
+## |  Last changed by: $Author: wassmer $
 ## |
 ## |
 
@@ -31,8 +31,6 @@
 #
 # @keywords internal
 #
-
-
 .calcSurvivalTestStatistics <- function(dataInput, subset, stage, thetaH0,
         stratifiedAnalysis, directionUpper = TRUE) {
     overallEvents <- NA_real_
@@ -148,7 +146,7 @@
 
     .assertIsValidIntersectionTestEnrichment(design, intersectionTest)
 
-    if ((gMax > 2) && intersectionTest == "SpiessensDebois") {
+    if (gMax > 2 && intersectionTest == "SpiessensDebois") {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "gMax (", gMax,
             ") > 2: Spiessens & Debois intersection test test can only be used for one subset"
@@ -158,11 +156,11 @@
     if (!stratifiedAnalysis) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
-            "Only stratified analysis can be performed for enrichment survival designs"
+            "only stratified analysis can be performed for enrichment survival designs"
         )
     }
 
-    if (dataInput$isStratified() && (gMax > 4)) {
+    if (dataInput$isStratified() && gMax > 4) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "gMax (", gMax,
             ") > 4: Stratified analysis not implemented"
@@ -326,7 +324,9 @@
     .warnInCaseOfUnknownArguments(
         functionName = ".getAnalysisResultsSurvivalInverseNormalEnrichment",
         ignore = c(.getDesignArgumentsToIgnoreAtUnknownArgumentCheck(
-            design, powerCalculationEnabled = TRUE), "stage"), ...
+            design,
+            powerCalculationEnabled = TRUE
+        ), "stage"), ...
     )
 
     results <- AnalysisResultsEnrichmentInverseNormal(design = design, dataInput = dataInput)
@@ -476,9 +476,9 @@
 
     for (k in 1:design$kMax) {
         for (population in 1:gMax) {
-            results$repeatedConfidenceIntervalLowerBounds[population, k] <- 
+            results$repeatedConfidenceIntervalLowerBounds[population, k] <-
                 repeatedConfidenceIntervals[population, 1, k]
-            results$repeatedConfidenceIntervalUpperBounds[population, k] <- 
+            results$repeatedConfidenceIntervalUpperBounds[population, k] <-
                 repeatedConfidenceIntervals[population, 2, k]
         }
     }
@@ -496,9 +496,8 @@
 }
 
 .getRootThetaSurvivalEnrichment <- function(..., design, dataInput, treatmentArm, stage,
-        directionUpper, stratifiedAnalysis, intersectionTest, thetaLow, thetaUp, 
+        directionUpper, stratifiedAnalysis, intersectionTest, thetaLow, thetaUp,
         firstParameterName, secondValue, tolerance) {
-        
     result <- .getOneDimensionalRoot(
         function(theta) {
             stageResults <- .getStageResultsSurvivalEnrichment(
@@ -516,11 +515,10 @@
     return(result)
 }
 
-.getUpperLowerThetaSurvivalEnrichment <- function(..., 
+.getUpperLowerThetaSurvivalEnrichment <- function(...,
         design, dataInput, theta, treatmentArm, stage,
-        directionUpper, conditionFunction, stratifiedAnalysis, 
+        directionUpper, conditionFunction, stratifiedAnalysis,
         intersectionTest, firstParameterName, secondValue) {
-        
     stageResults <- .getStageResultsSurvivalEnrichment(
         design = design, dataInput = dataInput,
         stage = stage, thetaH0 = exp(theta), directionUpper = directionUpper,
@@ -590,6 +588,8 @@
         bounds <- design$futilityBounds
         border <- C_FUTILITY_BOUNDS_DEFAULT
         criticalValues <- design$criticalValues
+        criticalValues[is.infinite(criticalValues) & criticalValues > 0] <- C_QNORM_MAXIMUM
+        criticalValues[is.infinite(criticalValues) & criticalValues < 0] <- C_QNORM_MINIMUM
         conditionFunction <- .isFirstValueGreaterThanSecondValue
     }
 
@@ -607,13 +607,13 @@
     stages <- (1:stage)
     for (k in stages) {
         startTime <- Sys.time()
-        for (g in 1:gMax) {
-            if (!is.na(stageResults$testStatistics[g, k])) {
-
+        for (population in 1:gMax) {
+			if (!is.na(stageResults$testStatistics[population, k]) && criticalValues[k] < C_QNORM_MAXIMUM) {
+				
                 # Finding maximum upper and minimum lower bounds for RCIs
                 thetaLow <- exp(.getUpperLowerThetaSurvivalEnrichment(
                     design = design, dataInput = dataInput,
-                    theta = -1, treatmentArm = g, stage = k, directionUpper = TRUE,
+                    theta = -1, treatmentArm = population, stage = k, directionUpper = TRUE,
                     stratifiedAnalysis = stratifiedAnalysis, intersectionTest = intersectionTest,
                     conditionFunction = conditionFunction, firstParameterName = firstParameterName,
                     secondValue = criticalValues[k]
@@ -621,24 +621,24 @@
 
                 thetaUp <- exp(.getUpperLowerThetaSurvivalEnrichment(
                     design = design, dataInput = dataInput,
-                    theta = 1, treatmentArm = g, stage = k, directionUpper = FALSE,
+                    theta = 1, treatmentArm = population, stage = k, directionUpper = FALSE,
                     stratifiedAnalysis = stratifiedAnalysis, intersectionTest = intersectionTest,
                     conditionFunction = conditionFunction, firstParameterName = firstParameterName,
                     secondValue = criticalValues[k]
                 ))
 
                 # finding upper and lower RCI limits through root function
-                repeatedConfidenceIntervals[g, 1, k] <- .getRootThetaSurvivalEnrichment(
+                repeatedConfidenceIntervals[population, 1, k] <- .getRootThetaSurvivalEnrichment(
                     design = design,
-                    dataInput = dataInput, treatmentArm = g, stage = k, directionUpper = TRUE,
+                    dataInput = dataInput, treatmentArm = population, stage = k, directionUpper = TRUE,
                     thetaLow = thetaLow, thetaUp = thetaUp, stratifiedAnalysis = stratifiedAnalysis,
                     intersectionTest = intersectionTest, firstParameterName = firstParameterName,
                     secondValue = criticalValues[k], tolerance = tolerance
                 )
 
-                repeatedConfidenceIntervals[g, 2, k] <- .getRootThetaSurvivalEnrichment(
+                repeatedConfidenceIntervals[population, 2, k] <- .getRootThetaSurvivalEnrichment(
                     design = design,
-                    dataInput = dataInput, treatmentArm = g, stage = k, directionUpper = FALSE,
+                    dataInput = dataInput, treatmentArm = population, stage = k, directionUpper = FALSE,
                     thetaLow = thetaLow, thetaUp = thetaUp, stratifiedAnalysis = stratifiedAnalysis,
                     intersectionTest = intersectionTest, firstParameterName = firstParameterName,
                     secondValue = criticalValues[k], tolerance = tolerance
@@ -657,7 +657,7 @@
                         thetaUp <- .getUpperLowerThetaSurvivalEnrichment(
                             design = design,
                             dataInput = dataInput,
-                            theta = 1, treatmentArm = g, stage = k - 1, directionUpper = FALSE,
+                            theta = 1, treatmentArm = population, stage = k - 1, directionUpper = FALSE,
                             conditionFunction = conditionFunction, stratifiedAnalysis = stratifiedAnalysis,
                             intersectionTest = intersectionTest, firstParameterName = parameterName,
                             secondValue = bounds[k - 1]
@@ -666,29 +666,29 @@
 
                     futilityCorr[k] <- .getRootThetaSurvivalEnrichment(
                         design = design, dataInput = dataInput,
-                        treatmentArm = g, stage = k - 1, directionUpper = directionUpper,
+                        treatmentArm = population, stage = k - 1, directionUpper = directionUpper,
                         thetaLow = thetaLow, thetaUp = thetaUp, stratifiedAnalysis = stratifiedAnalysis,
                         intersectionTest = intersectionTest, firstParameterName = parameterName,
                         secondValue = bounds[k - 1], tolerance = tolerance
                     )
 
                     if (directionUpper) {
-                        repeatedConfidenceIntervals[g, 1, k] <- min(
+                        repeatedConfidenceIntervals[population, 1, k] <- min(
                             min(futilityCorr[2:k]),
-                            repeatedConfidenceIntervals[g, 1, k]
+                            repeatedConfidenceIntervals[population, 1, k]
                         )
                     } else {
-                        repeatedConfidenceIntervals[g, 2, k] <- max(
+                        repeatedConfidenceIntervals[population, 2, k] <- max(
                             max(futilityCorr[2:k]),
-                            repeatedConfidenceIntervals[g, 2, k]
+                            repeatedConfidenceIntervals[population, 2, k]
                         )
                     }
                 }
 
-                if (!is.na(repeatedConfidenceIntervals[g, 1, k]) &&
-                        !is.na(repeatedConfidenceIntervals[g, 2, k]) &&
-                        repeatedConfidenceIntervals[g, 1, k] > repeatedConfidenceIntervals[g, 2, k]) {
-                    repeatedConfidenceIntervals[g, , k] <- rep(NA_real_, 2)
+                if (!is.na(repeatedConfidenceIntervals[population, 1, k]) &&
+                        !is.na(repeatedConfidenceIntervals[population, 2, k]) &&
+                        repeatedConfidenceIntervals[population, 1, k] > repeatedConfidenceIntervals[population, 2, k]) {
+                    repeatedConfidenceIntervals[population, , k] <- rep(NA_real_, 2)
                 }
             }
         }
@@ -711,7 +711,9 @@
         functionName =
             ".getRepeatedConfidenceIntervalsSurvivalEnrichmentInverseNormal",
         ignore = c(.getDesignArgumentsToIgnoreAtUnknownArgumentCheck(
-            design, powerCalculationEnabled = TRUE), "stage"), ...
+            design,
+            powerCalculationEnabled = TRUE
+        ), "stage"), ...
     )
 
     return(.getRepeatedConfidenceIntervalsSurvivalEnrichmentAll(
@@ -735,7 +737,9 @@
         functionName =
             ".getRepeatedConfidenceIntervalsSurvivalEnrichmentFisher",
         ignore = c(.getDesignArgumentsToIgnoreAtUnknownArgumentCheck(
-            design, powerCalculationEnabled = TRUE), "stage"), ...
+            design,
+            powerCalculationEnabled = TRUE
+        ), "stage"), ...
     )
 
     return(.getRepeatedConfidenceIntervalsSurvivalEnrichmentAll(
@@ -875,16 +879,16 @@
     ctr <- .performClosedCombinationTest(stageResults = stageResults)
     criticalValues <- design$criticalValues
 
-    for (g in 1:gMax) {
-        if (!is.na(ctr$separatePValues[g, stage])) {
+    for (population in 1:gMax) {
+        if (!is.na(ctr$separatePValues[population, stage])) {
             # shifted decision region for use in getGroupSeqProbs
             # Inverse Normal Method
             shiftedDecisionRegionUpper <- criticalValues[(stage + 1):kMax] *
                 sqrt(sum(weights[1:stage]^2) + cumsum(weights[(stage + 1):kMax]^2)) /
                 sqrt(cumsum(weights[(stage + 1):kMax]^2)) -
-                min(ctr$overallAdjustedTestStatistics[ctr$indices[, g] == 1, stage], na.rm = TRUE) *
+                min(ctr$overallAdjustedTestStatistics[ctr$indices[, population] == 1, stage], na.rm = TRUE) *
                     sqrt(sum(weights[1:stage]^2)) /
-                    sqrt(cumsum(weights[(stage + 1):kMax]^2)) - standardizedEffect[g] *
+                    sqrt(cumsum(weights[(stage + 1):kMax]^2)) - standardizedEffect[population] *
                     cumsum(sqrt(nPlanned[(stage + 1):kMax]) * weights[(stage + 1):kMax]) /
                     sqrt(cumsum(weights[(stage + 1):kMax]^2))
             if (stage == kMax - 1) {
@@ -893,9 +897,9 @@
                 shiftedFutilityBounds <- design$futilityBounds[(stage + 1):(kMax - 1)] *
                     sqrt(sum(weights[1:stage]^2) + cumsum(weights[(stage + 1):(kMax - 1)]^2)) /
                     sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2)) -
-                    min(ctr$overallAdjustedTestStatistics[ctr$indices[, g] == 1, stage], na.rm = TRUE) *
+                    min(ctr$overallAdjustedTestStatistics[ctr$indices[, population] == 1, stage], na.rm = TRUE) *
                         sqrt(sum(weights[1:stage]^2)) /
-                        sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2)) - standardizedEffect[g] *
+                        sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2)) - standardizedEffect[population] *
                         cumsum(sqrt(nPlanned[(stage + 1):(kMax - 1)]) * weights[(stage + 1):(kMax - 1)]) /
                         sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2))
             }
@@ -914,7 +918,7 @@
                 informationRates = scaledInformation
             )
 
-            results$conditionalPower[g, (stage + 1):kMax] <- cumsum(probs[3, ] - probs[2, ])
+            results$conditionalPower[population, (stage + 1):kMax] <- cumsum(probs[3, ] - probs[2, ])
         }
     }
 
@@ -964,13 +968,13 @@
     nPlanned <- c(rep(NA_real_, stage), nPlanned)
     nPlanned <- allocationRatioPlanned / (1 + allocationRatioPlanned)^2 * nPlanned
     ctr <- .performClosedCombinationTest(stageResults = stageResults)
-    for (g in 1:gMax) {
-        if (!is.na(ctr$separatePValues[g, stage])) {
+    for (population in 1:gMax) {
+        if (!is.na(ctr$separatePValues[population, stage])) {
             if (gMax == 1) {
-                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, g] == 1, ][1:stage]
+                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, population] == 1, ][1:stage]
             } else {
-                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, g] == 1, ][which.max(
-                    ctr$overallAdjustedTestStatistics[ctr$indices[, g] == 1, stage]
+                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, population] == 1, ][which.max(
+                    ctr$overallAdjustedTestStatistics[ctr$indices[, population] == 1, stage]
                 ), 1:stage]
             }
             if (stage < kMax - 1) {
@@ -980,11 +984,11 @@
                         reject <- reject + .getRejectValueConditionalPowerFisher(
                             kMax = kMax, alpha0Vec = design$alpha0Vec,
                             criticalValues = criticalValues, weightsFisher = weightsFisher,
-                            pValues = pValues, currentKMax = k, thetaH1 = standardizedEffect[g],
+                            pValues = pValues, currentKMax = k, thetaH1 = standardizedEffect[population],
                             stage = stage, nPlanned = nPlanned
                         )
                     }
-                    results$conditionalPower[g, k] <- reject / iterations
+                    results$conditionalPower[population, k] <- reject / iterations
                 }
                 results$simulated <- TRUE
                 results$.setParameterType("simulated", C_PARAM_GENERATED)
@@ -994,10 +998,10 @@
 
                 if (result <= 0 || result >= 1) {
                     warning("Calculation not possible: could not calculate conditional power for stage ", kMax, call. = FALSE)
-                    results$conditionalPower[g, kMax] <- NA_real_
+                    results$conditionalPower[population, kMax] <- NA_real_
                 } else {
-                    results$conditionalPower[g, kMax] <- 1 - stats::pnorm(.getQNorm(result) -
-                        standardizedEffect[g] * sqrt(nPlanned[kMax]))
+                    results$conditionalPower[population, kMax] <- 1 - stats::pnorm(.getQNorm(result) -
+                        standardizedEffect[population] * sqrt(nPlanned[kMax]))
                 }
             }
         }
@@ -1052,8 +1056,8 @@
 
     j <- 1
     for (i in seq(along = thetaRange)) {
-        for (g in (1:gMax)) {
-            populations[j] <- g
+        for (population in (1:gMax)) {
+            populations[j] <- population
             effectValues[j] <- thetaRange[i]
 
             if (.isTrialDesignInverseNormal(design)) {
@@ -1062,7 +1066,7 @@
                     design = design, stageResults = stageResults, stage = stage, nPlanned = nPlanned,
                     allocationRatioPlanned = allocationRatioPlanned,
                     thetaH1 = thetaRange[i], ...
-                )$conditionalPower[g, kMax]
+                )$conditionalPower[population, kMax]
             } else if (.isTrialDesignFisher(design)) {
                 condPowerValues[j] <- .getConditionalPowerSurvivalEnrichmentFisher(
                     results = results,
@@ -1070,12 +1074,12 @@
                     allocationRatioPlanned = allocationRatioPlanned,
                     thetaH1 = thetaRange[i],
                     iterations = iterations, seed = seed, ...
-                )$conditionalPower[g, kMax]
+                )$conditionalPower[population, kMax]
             }
             likelihoodValues[j] <- stats::dnorm(
-                log(thetaRange[i]), log(stageResults$effectSizes[g, stage]),
-                stdErr[g]
-            ) / stats::dnorm(0, 0, stdErr[g])
+                log(thetaRange[i]), log(stageResults$effectSizes[population, stage]),
+                stdErr[population]
+            ) / stats::dnorm(0, 0, stdErr[population])
             j <- j + 1
         }
     }
